@@ -6,11 +6,13 @@ use Carp;
 use List::MoreUtils qw/any/;
 use Encode;
 
-our @EXPORT = qw/true false DEBUG normalize_channel_name daemonize decorate_irc_color U/;
+our @EXPORT = qw/true false DEBUG normalize_channel_name daemonize decorate_irc_color U irc_nick global_context/;
 
 sub true  () { 1 } ## no critic.
 sub false () { 0 } ## no critic.
 
+sub global_context () { App::Mobirc->context }
+
 sub U ($) { decode('utf-8', shift) } ## no critic.
 
 sub DEBUG($) { ## no critic.
@@ -18,6 +20,8 @@ sub DEBUG($) { ## no critic.
     print STDERR "$txt\n" if $ENV{DEBUG};
 }
 
+sub irc_nick () { POE::Kernel->alias_resolve('irc_session')->get_heap->{irc}->nick_name } ## no critic
+
 # -------------------------------------------------------------------------
 
 sub normalize_channel_name {
@@ -31,8 +35,19 @@ sub normalize_channel_name {
 sub daemonize {
     my $pid_fname = shift;
 
-    require Proc::Daemon;
-    Proc::Daemon::Init();
+    if (my $pid = fork) {
+        exit 0; 
+    } elsif (defined $pid) {
+        close(STDIN);
+        close(STDOUT);
+        close(STDERR);
+
+        open(STDIN,  "+>/dev/null"); ## no critic.
+        open(STDOUT, "+>&STDIN");    ## no critic.
+        open(STDERR, "+>&STDIN");    ## no critic.
+    } else {
+        die "fork failed: $@";
+    }
 
     if ( defined $pid_fname ) {
         open my $pid, '>', $pid_fname or die "cannot open pid file: $pid_fname";
@@ -41,5 +56,4 @@ sub daemonize {
     }
 }
 
-
 1;
